@@ -67,12 +67,17 @@ class sqlrconnection {
 				// Returns true on success and false on failure.
 
 
-		bool	ping();
+		bool		ping();
 				// Returns true if the database is up and false
 				// if it's down.
 		const char	*identify();
 				// Returns the type of database: 
-				//   oracle7, oracle8, postgresql, mysql, etc.
+				//   oracle8, postgresql, mysql, etc.
+		const char	*dbVersion();
+				// Returns the version of the database
+		const char	*bindFormat();
+				// Returns a string representing the format
+				// of the bind variables used in the db.
 
 
 		bool	autoCommitOn();
@@ -270,6 +275,10 @@ class sqlrcursor {
 				// query.  There is a performance penalty for
 				// calling this method.
 
+		bool	validBind(const char *variable);
+				// Returns true if "variable" was a valid
+				// bind variable of the query.
+
 		bool	executeQuery();
 				// Execute the query that was previously 
 				// prepared and bound.
