@@ -63,7 +63,12 @@ int	sqlrcon_ping(sqlrcon sqlrconref);
 			   if it's down. */
 const char	*sqlrcon_identify(sqlrcon sqlrconref); 
 			/* Returns the type of database: 
-			     oracle7, oracle8, postgresql, mysql, etc. */
+			     oracle8, postgresql, mysql, etc. */
+const char	*sqlrcon_dbVersion(sqlrcon sqlrconref); 
+			/* Returns the version of the database */
+const char	*sqlrcon_bindFormat(sqlrcon sqlrconref); 
+			/* Returns a string representing the format
+			   of the bind variables used in the db. */
 
 int	sqlrcon_autoCommitOn(sqlrcon sqlrconref);
 			/* Instructs the database to perform a commit
@@ -271,6 +276,10 @@ void	sqlrcur_validateBinds(sqlrcur sqlrcurref);
 			   query.  There is a performance penalty for
 			   calling this function */
 
+int	sqlrcur_validBind(sqlrcur sqlrcurref, const char *variable);
+			/* Returns true if "variable" was a valid
+			   bind variable of the query. */
+
 int	sqlrcur_executeQuery(sqlrcur sqlrcurref);
 			/* Execute the query that was previously prepared 
 			   and bound. */
