@@ -6,7 +6,7 @@ package SQLRelay::Connection;
 require DynaLoader;
 @ISA = 'DynaLoader';
 
-$VERSION = '0.37.1';
+$VERSION = '0.39.3';
 
 bootstrap SQLRelay::Connection $VERSION;
 
@@ -93,8 +93,14 @@ __END__
 
         identify();
             # Returns the type of database:
-            #   oracle7, oracle8, postgresql, mysql, etc.
+            #   oracle8, postgresql, mysql, etc.
 
+        dbVersion();
+            # Returns the version of the database
+
+        bindFormat();
+            # Returns a string representing the format
+            # of the bind variables used in the db.
 
         autoCommitOn();
             # Instructs the database to perform a commit
