@@ -6,7 +6,7 @@ package SQLRelay::Cursor;
 require DynaLoader;
 @ISA = 'DynaLoader';
 
-$VERSION = '0.37.1';
+$VERSION = '0.39.3';
 
 bootstrap SQLRelay::Cursor $VERSION;
 
@@ -255,6 +255,10 @@ __END__
             # to bind them unless they really are in the 
             # query.
 
+        validBind(variable);
+            # Returns true if "variable" was a valid
+            # bind variable of the query.
+
         executeQuery();
             # Execute the query that was previously 
             # prepared and bound.
