@@ -13,10 +13,10 @@
 // | obtain it through the world-wide-web, please send a note to          |
 // | license@php.net so we can mail you a copy immediately.               |
 // +----------------------------------------------------------------------+
-// | Author: David Muse <ssb@php.net>                                    |
+// | Author: David Muse <david.muse@firstworks.com>                       |
 // +----------------------------------------------------------------------+
 //
-// $Id: sqlrelay.php,v 1.21 2006/09/09 02:57:02 mused Exp $
+// $Id: sqlrelay.php,v 1.26 2007/05/03 02:56:51 mused Exp $
 //
 // Database independent query interface definition for PHP's SQLRelay
 // extension.
@@ -44,12 +44,20 @@ class DB_sqlrelay extends DB_common
 
     var $connection;
     var $identity = "";
-    var $phptype, $dbsyntax;
+    var $bindformat = "";
+    var $phptype = "sqlrelay";
+    var $dbsyntax = "sqlrelay";
     var $autocommit = false;
     var $fetchmode = DB_FETCHMODE_ORDERED; /* Default fetch mode */
     var $affectedrows = 0;
     var $prepare_types = array();
     var $is_select = array();
+    var $features = array(
+            'prepare' => true,
+            'pconnect' => true,
+            'transactions' => true,
+            'limit' => 'emulate'
+        );
 
 
     // }}}
@@ -64,14 +72,6 @@ class DB_sqlrelay extends DB_common
     function DB_sqlrelay()
     {
         $this->DB_common();
-        $this->phptype = 'sqlrelay';
-        $this->dbsyntax = 'sqlrelay';
-        $this->features = array(
-            'prepare' => true,
-            'pconnect' => true,
-            'transactions' => true,
-            'limit' => 'emulate'
-        );
     }
 
     // }}}
@@ -210,6 +210,12 @@ class DB_sqlrelay extends DB_common
             $this->identity = sqlrcon_identify($this->connection);
         }
 
+        if ($this->bindformat == "") {
+echo("bindformat is ".$this->bindformat."\n");
+            $this->bindformat = sqlrcon_bindFormat($this->connection);
+echo("bindformat is ".$this->bindformat."\n");
+        }
+
         $cursor = sqlrcur_alloc($this->connection);
 
         if ($this->options['portability'] & DB_PORTABILITY_LOWERCASE) {
@@ -227,8 +233,7 @@ class DB_sqlrelay extends DB_common
         # : or @ delimited variables
         # for db's which already uses ?-delimited variables, we don't need
         # to do this...
-        # FIXME: handle postgresql 8 and mysql 4.1
-        if ($this->identity == "db2" || $this->identity == "interbase") {
+        if ($this->bindformat == "?") {
             $newquery = $query;
         } else {
             $paramindex = 0;
@@ -245,9 +250,10 @@ class DB_sqlrelay extends DB_common
                     } else {
                         $types[$paramindex] = DB_PARAM_OPAQUE;
                     }
-                    if ($this->identity == "sybase" ||
-                            $this->identity == "freetds") {
+                    if ($this->bindformat == "@*") {
                         $newquery .= "@bind" . $paramindex;
+                    } else if ($this->bindformat == "$1") {
+                        $newquery .= "$" . ($paramindex+1);
                     } else {
                         $newquery .= ":bind" . $paramindex;
                     }
@@ -343,6 +349,7 @@ class DB_sqlrelay extends DB_common
             return $this->raiseError(DB_ERROR_NEED_MORE_DATA);
         }
         $first = true;
+        $pgbindindex = 1;
         switch ($mode) {
             case DB_AUTOQUERY_INSERT:
                 $values = '';
@@ -355,10 +362,11 @@ class DB_sqlrelay extends DB_common
                         $values .= ',';
                     }
                     $names .= $value;
-                    # FIXME: handle other db formats too
-                    if ($this->identity == "sybase" ||
-                                $this->identity == "freetds") {
+                    if ($this->bindformat == "@*") {
                         $values .= "@$value";
+                    } else if ($this->bindformat == "$1") {
+                        $values .= "$" . $pgbindindex;
+                        $pgbindindex++;
                     } else {
                         $values .= ":$value";
                     }
@@ -373,9 +381,11 @@ class DB_sqlrelay extends DB_common
                         $set .= ',';
                     }
                     # FIXME: handle other db formats too
-                    if ($this->identity == "sybase" ||
-                                $this->identity == "freetds") {
+                    if ($this->bindformat == "@*") {
                         $set .= "$value = @$value";
+                    } else if ($this->bindformat == "$1") {
+                        $set .= "$value = $" . $pgbindindex;
+                        $pgbindindex++;
                     } else {
                         $set .= "$value = :$value";
                     }
