@@ -78,10 +78,23 @@ class sqlrconnection:
     def identify(self):
         """
         Returns the type of database: 
-          oracle7, oracle8, postgresql, mysql, etc.
+          oracle8, postgresql, mysql, etc.
         """
         return CSQLRelay.identify(self.connection)
 
+    def dbVersion(self):
+        """
+        Returns the version of the database
+        """
+        return CSQLRelay.dbVersion(self.connection)
+
+    def bindFormat(self):
+        """
+        Returns a string representing the format
+        of the bind variables used in the db.
+        """
+        return CSQLRelay.bindFormat(self.connection)
+
     def autoCommitOn(self):
         """
         Instructs the database to perform a commit
@@ -294,9 +307,9 @@ class sqlrcursor:
     def substitution(self, variable, value, precision=0, scale=0):
         """
         Define a substitution variable.
-	Returns true if the variable was successfully substituted or false if
-	the variable isn't a string, integer or floating point number, or if
-	precision and scale aren't provided for a floating point number.
+        Returns true if the variable was successfully substituted or false if
+        the variable isn't a string, integer or floating point number, or if
+        precision and scale aren't provided for a floating point number.
         """
         return CSQLRelay.substitution(self.cursor,variable,value,precision,scale)
 
@@ -307,19 +320,19 @@ class sqlrcursor:
         return CSQLRelay.clearBinds(self.cursor)
 
     def countBindVariables(self):
-	"""
+        """
         Parses the previously prepared query,
         counts the number of bind variables defined
         in it and returns that number.
-	"""
+        """
         return CSQLRelay.countBindVariables(self.cursor)
 
     def inputBind(self, variable, value, precision=0, scale=0):
         """
         Define an input bind varaible.
-	Returns true if the variable was successfully bound or false if the
-	variable isn't a string, integer or floating point number, or if
-	precision and scale aren't provided for a floating point number.
+        Returns true if the variable was successfully bound or false if the
+        variable isn't a string, integer or floating point number, or if
+        precision and scale aren't provided for a floating point number.
         """
         return CSQLRelay.inputBind(self.cursor, variable, value, precision, scale)
 
@@ -374,18 +387,18 @@ class sqlrcursor:
     def substitutions(self, variables, values, precisions=None, scales=None):
         """
         Define substitution variables.
-	Returns true if the variables were successfully substituted or false if
-	one of the variables wasn't a string, integer or floating point number,
-	or if precision and scale weren't provided for a floating point number.
+        Returns true if the variables were successfully substituted or false if
+        one of the variables wasn't a string, integer or floating point number,
+        or if precision and scale weren't provided for a floating point number.
         """
         return CSQLRelay.substitutions(self.cursor,variables,values,precisions,scales)
 
     def inputBinds(self, variables, values, precisions=None, scales=None):
         """
         Define input bind variables.
-	Returns true if the variables were successfully bound or false if one
-	of the variables wasn't a string, integer or floating point number,
-	or if precision and scale weren't provided for a floating point number.
+        Returns true if the variables were successfully bound or false if one
+        of the variables wasn't a string, integer or floating point number,
+        or if precision and scale weren't provided for a floating point number.
         """
         return CSQLRelay.inputBinds(self.cursor,variables,values,precisions,scales)
         
@@ -399,6 +412,15 @@ class sqlrcursor:
         query.
         """
         return CSQLRelay.validateBinds(self.cursor)
+        
+
+    def validBind(self,variable):
+        """
+	Returns true if "variable" was a valid
+	input bind variable of the query.
+        """
+        return CSQLRelay.validBind(self.cursor,variable)
+        
 
     def executeQuery(self):
         """
