@@ -9,10 +9,10 @@ import time
 
 
 def main():
-    if len(sys.argv) != 6:
+    if len(sys.argv) != 7:
         print "usage:    query.py host port socket user password query"
         sys.exit(0)
-    con = PySQLRClient.sqlrconnection(sys.argv[1],sys.argv[2],sys.argv[3],sys.argv[4],sys.argv[5])
+    con = PySQLRClient.sqlrconnection(sys.argv[1],int(sys.argv[2]),sys.argv[3],sys.argv[4],sys.argv[5],0,1)
     cur = PySQLRClient.sqlrcursor(con)
     cur.sendQuery(sys.argv[6])
     for row in range(cur.rowCount()):
