@@ -11,8 +11,6 @@
 #define DONT_SEND_COLUMN_INFO 0
 
 #define NEW_QUERY 0
-#define REEXECUTE_QUERY 13
-#define FETCH_FROM_BIND_CURSOR 14
 #define FETCH_RESULT_SET 1
 #define ABORT_RESULT_SET 2
 #define SUSPEND_RESULT_SET 3
@@ -25,6 +23,10 @@
 #define ROLLBACK 10
 #define AUTHENTICATE 11
 #define AUTOCOMMIT 12
+#define REEXECUTE_QUERY 13
+#define FETCH_FROM_BIND_CURSOR 14
+#define DBVERSION 15
+#define BINDFORMAT 16
 
 #define ERROR 0
 #define NO_ERROR 1
