@@ -2,7 +2,6 @@
 // See the file COPYING for more information.
 
 char	*databaselist[]={
-	"oracle7",
 	"oracle8",
 	"mysql",
 	"postgresql",
@@ -10,7 +9,7 @@ char	*databaselist[]={
 	"freetds",
 	"sybase",
 	"db2",
-	"interbase",
+	"firebird",
 	"odbc",
 	"mdbtools",
 	(char *)NULL
