@@ -44,8 +44,7 @@ class sqlrconnection_svr :
 			sqlrconnection_svr();
 		virtual	~sqlrconnection_svr();
 
-		bool	initConnection(int argc, const char **argv,
-						bool detachbeforeloggingin);
+		bool	initConnection(int argc, const char **argv);
 		void	listen();
 		void	closeConnection();
 
@@ -65,6 +64,8 @@ class sqlrconnection_svr :
 		virtual const char	*pingQuery();
 		virtual bool		ping();
 		virtual const char	*identify()=0;
+		virtual	const char	*dbVersion()=0;
+		virtual	const char	*bindFormat();
 		virtual sqlrcursor_svr	*initCursor()=0;
 		virtual void	deleteCursor(sqlrcursor_svr *curs)=0;
 		virtual	int16_t	nonNullBindValue();
@@ -144,6 +145,8 @@ class sqlrconnection_svr :
 		bool		createSharedMemoryAndSemaphores(
 							const char *tmpdir,
 							const char *id);
+		void		cleanUpAllCursorData(bool freeresult,
+							bool freebinds);
 
 	private:
 		// methods used internally
@@ -157,7 +160,7 @@ class sqlrconnection_svr :
 							bool execute);
 
 		void	setUserAndGroup();
-		bool	initCursors(bool create);
+		bool	initCursors();
 		void	incrementConnectionCount();
 		void	decrementConnectionCount();
 		void	decrementSessionCount();
@@ -212,6 +215,8 @@ class sqlrconnection_svr :
 		void	autoCommitCommand();
 		void	commitCommand();
 		void	rollbackCommand();
+		void	dbVersionCommand();
+		void	bindFormatCommand();
 		bool	newQueryCommand(sqlrcursor_svr *cursor);
 		bool	reExecuteQueryCommand(sqlrcursor_svr *cursor);
 		bool	fetchFromBindCursorCommand(sqlrcursor_svr *cursor);
@@ -272,7 +277,7 @@ class sqlrconnection_svr :
 		void	markDatabaseAvailable();
 
 		void	blockSignals();
-		bool	attemptLogIn();
+		bool	attemptLogIn(bool printerrors);
 		void	setInitialAutoCommitBehavior();
 		bool	openSockets();
 
@@ -348,6 +353,11 @@ class sqlrconnection_svr :
 		uint32_t	maxlobbindvaluelength;
 		int32_t		idleclienttimeout;
 
+		bool		decrementonclose;
+		bool		silent;
+
+		file		querylog;
+
 #ifdef SERVER_DEBUG
 		stringbuffer	*debugstr;
 #endif
