@@ -129,12 +129,16 @@ class db2connection : public sqlrconnection_svr {
 		bool	rollback();
 		const char	*pingQuery();
 		const char	*identify();
+		const char	*dbVersion();
+		const char	*bindFormat();
 
 		SQLHENV		env;
 		SQLRETURN	erg;
 		SQLHDBC		dbc;
 
 		const char	*server;
+
+		char		dbversion[512];
 };
 
 #endif
