@@ -154,9 +154,13 @@ class freetdsconnection : public sqlrconnection_svr {
 		void	deleteCursor(sqlrcursor_svr *curs);
 		void	logOut();
 		const char	*identify();
+		const char	*dbVersion();
+		const char	*bindFormat();
 		char	bindVariablePrefix();
 		void	dropTempTable(sqlrcursor_svr *cursor,
 					const char *tablename);
+		bool		commit();
+		bool		rollback();
 
 		CS_CONTEXT	*context;
 		CS_LOCALE	*locale;
@@ -171,6 +175,10 @@ class freetdsconnection : public sqlrconnection_svr {
 		const char	*hostname;
 		const char	*packetsize;
 
+		bool		dbused;
+
+		char		*dbversion;
+
 		static	stringbuffer	*errorstring;
 		static	bool		deadconnection;
 
