@@ -98,7 +98,7 @@ class mysqlcursor : public sqlrcursor_svr {
 
 		bool		usestmtprepare;
 
-		regularexpression	storedproc;
+		regularexpression	unsupportedbystmt;
 #endif
 		MYSQL_ROW	mysqlrow;
 		unsigned long	*mysqlrowlengths;
@@ -110,6 +110,7 @@ class mysqlconnection : public sqlrconnection_svr {
 	friend class mysqlcursor;
 	public:
 				mysqlconnection();
+				~mysqlconnection();
 	private:
 		uint16_t	getNumberOfConnectStringVars();
 		void		handleConnectString();
@@ -126,6 +127,8 @@ class mysqlconnection : public sqlrconnection_svr {
 		bool		ping();
 #endif
 		const char	*identify();
+		const char	*dbVersion();
+		const char	*bindFormat();
 		bool		autoCommitOn();
 		bool		autoCommitOff();
 		bool		commit();
@@ -134,6 +137,7 @@ class mysqlconnection : public sqlrconnection_svr {
 		short		nonNullBindValue();
 		short		nullBindValue();
 #endif
+		void		endSession();
 
 		MYSQL	mysql;
 		bool	connected;
@@ -143,9 +147,17 @@ class mysqlconnection : public sqlrconnection_svr {
 		const char	*port;
 		const char	*socket;
 
+		char	*dbversion;
+
+#ifdef MYSQL_OPT_RECONNECT
+		static const my_bool	mytrue;
+#endif
+
 #ifdef HAVE_MYSQL_STMT_PREPARE
 		bool		fakebinds;
 #endif
+
+		bool		firstquery;
 };
 
 #endif
