@@ -21,13 +21,15 @@ class postgresqlcursor : public sqlrcursor_svr {
 	private:
 				postgresqlcursor(sqlrconnection_svr *conn);
 				~postgresqlcursor();
-#ifdef HAVE_POSTGRESQL_PQEXECPREPARED
+#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)
 		bool		openCursor(uint16_t id);
 		bool		prepareQuery(const char *query,
 						uint32_t length);
 #endif
 		bool		supportsNativeBinds();
-#ifdef HAVE_POSTGRESQL_PQEXECPREPARED
+#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)
 		bool		inputBindString(const char *variable, 
 						uint16_t variablesize,
 						const char *value, 
@@ -79,7 +81,8 @@ class postgresqlcursor : public sqlrcursor_svr {
 
 		postgresqlconnection	*postgresqlconn;
 
-#ifdef HAVE_POSTGRESQL_PQEXECPREPARED
+#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)
 		bool		deallocatestatement;
 		int		bindcount;
 		int		bindcounter;
@@ -94,6 +97,9 @@ class postgresqlcursor : public sqlrcursor_svr {
 
 class postgresqlconnection : public sqlrconnection_svr {
 	friend class postgresqlcursor;
+	public:
+			postgresqlconnection();
+			~postgresqlconnection();
 	private:
 		uint16_t	getNumberOfConnectStringVars();
 		void		handleConnectString();
@@ -102,6 +108,8 @@ class postgresqlconnection : public sqlrconnection_svr {
 		void		deleteCursor(sqlrcursor_svr *curs);
 		void		logOut();
 		const char	*identify();
+		const char	*dbVersion();
+		const char	*bindFormat();
 
 		int	datatypecount;
 		int32_t	*datatypeids;
@@ -114,14 +122,13 @@ class postgresqlconnection : public sqlrconnection_svr {
 		const char	*options;
 		const char	*db;
 		uint16_t	typemangling;
-#ifdef HAVE_POSTGRESQL_PQEXECPREPARED
+#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)
 		bool		fakebinds;
 #endif
+		char		*dbversion;
 
 #ifndef HAVE_POSTGRESQL_PQSETNOTICEPROCESSOR
-	public:
-			postgresqlconnection();
-			~postgresqlconnection();
 	private:
 		file	devnull;
 #endif
