@@ -14,6 +14,7 @@
 #include <rudiments/semaphoreset.h>
 #include <rudiments/sharedmemory.h>
 #include <rudiments/regularexpression.h>
+#include <rudiments/signalclasses.h>
 #include <authenticator.h>
 
 #include <cmdline.h>
@@ -46,20 +47,19 @@ class sqlrlistener : public daemonprocess, public listener, private debugfile {
 		void	listen();
 	private:
 		void	cleanUp();
-		void	setUserAndGroup(sqlrconfigfile *cfgfl);
-		bool	verifyAccessToConfigFile(const char *configfile,
-						sqlrconfigfile *cfgfl);
+		void	setUserAndGroup();
+		bool	verifyAccessToConfigFile(const char *configfile);
 		bool	handlePidFile(tempdir *tmpdir, const char *id);
-		void	handleDynamicScaling(sqlrconfigfile *cfgfl);
-		void	setHandoffMethod(sqlrconfigfile *cfgfl);
-		void	setIpPermissions(sqlrconfigfile *cfgfl);
+		void	handleDynamicScaling();
+		void	setHandoffMethod();
+		void	setIpPermissions();
 		bool	createSharedMemoryAndSemaphores(tempdir *tmpdir,
 								const char *id);
 		void	ipcFileError(const char *idfilename);
 		void	keyError(const char *idfilename);
 		void	shmError(const char *id, int shmid);
 		void	semError(const char *id, int semid);
-		bool	listenOnClientSockets(sqlrconfigfile *cfgfl);
+		bool	listenOnClientSockets();
 		bool	listenOnHandoffSocket(tempdir *tmpdir, const char *id);
 		bool	listenOnDeregistrationSocket(tempdir *tmpdir,
 								const char *id);
@@ -99,11 +99,16 @@ class sqlrlistener : public daemonprocess, public listener, private debugfile {
 						filedescriptor *clientsock);
 		void	flushWriteBuffer(filedescriptor *fd);
 
+		static void	alarmHandler();
+
 		bool		passdescriptor;
 
 		int32_t		maxconnections;
 		bool		dynamicscaling;
 
+		int64_t		maxlisteners;
+		uint64_t	listenertimeout;
+
 		char		*unixport;
 		char		*pidfile;
 
@@ -134,6 +139,14 @@ class sqlrlistener : public daemonprocess, public listener, private debugfile {
 
 		uint32_t		maxquerysize;
 		int32_t			idleclienttimeout;
+
+		bool			isforkedchild;
+
+		signalhandler		alarmhandler;
+		static	sqlrlistener	*staticlistener;
+
+		sqlrconfigfile		cfgfl;
+		uint32_t		runningconnections;
 };
 
 #endif
