@@ -301,10 +301,10 @@ int	main(int argc, char **argv) {
 	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testdatetime"),"DATETIME");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,10),"SMALLDATETIME");
 	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testsmalldatetime"),"SMALLDATETIME");
-	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,11),"CHAR");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testchar"),"CHAR");
-	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,12),"CHAR");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testvarchar"),"CHAR");
+	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,11),"LONGCHAR");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testchar"),"LONGCHAR");
+	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,12),"LONGCHAR");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testvarchar"),"LONGCHAR");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,13),"BIT");
 	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testbit"),"BIT");
 	printf("\n");
@@ -332,10 +332,10 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testdatetime"),8);
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,10),4);
 	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testsmalldatetime"),4);
-	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,11),40);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testchar"),40);
-	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,12),40);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testvarchar"),40);
+	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,11),80);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testchar"),80);
+	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,12),80);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testvarchar"),80);
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,13),1);
 	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testbit"),1);
 	printf("\n");
