@@ -77,9 +77,9 @@ class db2 {
 		String	floatvar;
 		String[]	cols;
 		String[]	fields;
-		int	port;
+		short	port;
 		String	socket;
-		int	id;
+		short	id;
 		String	filename;
 		long[]	fieldlens;
 	
@@ -90,7 +90,8 @@ class db2 {
 		}
 	
 		// instantiation
-		SQLRConnection con=new SQLRConnection(args[0],Integer.parseInt(args[1]), 
+		SQLRConnection con=new SQLRConnection(args[0],
+					(short)Integer.parseInt(args[1]), 
 						args[2],args[3],args[4],0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
@@ -165,9 +166,9 @@ class db2 {
 		checkSuccess(cur.sendQuery("create procedure testproc(in invar int, out outvar int) language sql begin set outvar = invar; end"),1);
 		cur.prepareQuery("call testproc(?,?)");
 		cur.inputBind("1",5);
-		cur.defineOutputBind("2",10);
+		cur.defineOutputBindInteger("2");
 		checkSuccess(cur.executeQuery(),1);
-		checkSuccess(cur.getOutputBind("2"),"5");
+		checkSuccess(cur.getOutputBindInteger("2"),5);
 		checkSuccess(cur.sendQuery("drop procedure testproc"),1);
 		System.out.println();
 	
@@ -283,7 +284,7 @@ class db2 {
 		System.out.println();
 	
 		System.out.println("TOTAL ROWS: ");
-		checkSuccess(cur.totalRows(),-1);
+		checkSuccess(cur.totalRows(),0);
 		System.out.println();
 	
 		System.out.println("FIRST ROW INDEX: ");
