@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 sub checkUndef {
 
@@ -55,9 +55,9 @@ if ($#ARGV+1<5) {
 
 
 # instantiation
-$con=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1], 
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 				$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur=Firstworks::SQLRCursor->new($con);
+$cur=SQLRelay::Cursor->new($con);
 
 # get database type
 print("IDENTIFY: \n");
@@ -86,6 +86,7 @@ print("\n");
 
 print("BIND BY POSITION: \n");
 $cur->prepareQuery("insert into testtable values (:1,:2,:3,:4,:5)");
+checkSuccess($cur->countBindVariables(),5);
 $cur->inputBind("1",2);
 $cur->inputBind("2","testchar2");
 $cur->inputBind("3","testvarchar2");
@@ -148,46 +149,46 @@ print("\n");
 
 print("OUTPUT BIND BY NAME: \n");
 $cur->prepareQuery("begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;");
-$cur->defineOutputBind("numvar",10);
-$cur->defineOutputBind("stringvar",10);
-$cur->defineOutputBind("floatvar",10);
+$cur->defineOutputBindInteger("numvar");
+$cur->defineOutputBindString("stringvar",10);
+$cur->defineOutputBindDouble("floatvar");
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBind("numvar");
-$stringvar=$cur->getOutputBind("stringvar");
-$floatvar=$cur->getOutputBind("floatvar");
-checkSuccessString($numvar,'1');
+$numvar=$cur->getOutputBindInteger("numvar");
+$stringvar=$cur->getOutputBindString("stringvar");
+$floatvar=$cur->getOutputBindDouble("floatvar");
+checkSuccessString($numvar,1);
 checkSuccessString($stringvar,'hello');
-checkSuccessString($floatvar,'2.5');
+checkSuccessString($floatvar,2.5);
 print("\n");
 
 print("OUTPUT BIND BY NAME WITH VALIDATION: \n");
 $cur->clearBinds();
-$cur->defineOutputBind("numvar",10);
-$cur->defineOutputBind("stringvar",10);
-$cur->defineOutputBind("floatvar",10);
-$cur->defineOutputBind("dummyvar",10);
+$cur->defineOutputBindInteger("numvar");
+$cur->defineOutputBindString("stringvar",10);
+$cur->defineOutputBindDouble("floatvar");
+$cur->defineOutputBindString("dummyvar",10);
 $cur->validateBinds();
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBind("numvar");
-$stringvar=$cur->getOutputBind("stringvar");
-$floatvar=$cur->getOutputBind("floatvar");
-checkSuccessString($numvar,'1');
+$numvar=$cur->getOutputBindInteger("numvar");
+$stringvar=$cur->getOutputBindString("stringvar");
+$floatvar=$cur->getOutputBindDouble("floatvar");
+checkSuccessString($numvar,1);
 checkSuccessString($stringvar,'hello');
-checkSuccessString($floatvar,'2.5');
+checkSuccessString($floatvar,2.5);
 print("\n");
 
 print("OUTPUT BIND BY POSITION: \n");
 $cur->prepareQuery("begin  :1:=1; :2:='hello'; :3:=2.5; end;");
-$cur->defineOutputBind("1",10);
-$cur->defineOutputBind("2",10);
-$cur->defineOutputBind("3",10);
+$cur->defineOutputBindInteger("1");
+$cur->defineOutputBindString("2",10);
+$cur->defineOutputBindDouble("3");
 checkSuccess($cur->executeQuery(),1);
-$numvar=$cur->getOutputBind("1");
-$stringvar=$cur->getOutputBind("2");
-$floatvar=$cur->getOutputBind("3");
-checkSuccessString($numvar,'1');
+$numvar=$cur->getOutputBindInteger("1");
+$stringvar=$cur->getOutputBindString("2");
+$floatvar=$cur->getOutputBindDouble("3");
+checkSuccessString($numvar,1);
 checkSuccessString($stringvar,'hello');
-checkSuccessString($floatvar,'2.5');
+checkSuccessString($floatvar,2.5);
 print("\n");
 
 print("SELECT: \n");
@@ -254,7 +255,7 @@ checkSuccess($cur->rowCount(),8);
 print("\n");
 
 print("TOTAL ROWS: \n");
-checkSuccess($cur->totalRows(),-1);
+checkSuccess($cur->totalRows(),0);
 print("\n");
 
 print("FIRST ROW INDEX: \n");
@@ -380,9 +381,9 @@ print("\n");
 
 print("OUTPUT BIND: \n");
 $cur->prepareQuery("begin :var1:='hello'; end;");
-$cur->defineOutputBind("var1",10);
+$cur->defineOutputBindString("var1",10);
 checkSuccess($cur->executeQuery(),1);
-checkSuccessString($cur->getOutputBind("var1"),"hello");
+checkSuccessString($cur->getOutputBindString("var1"),"hello");
 print("\n");
 
 print("ARRAY SUBSTITUTIONS: \n");
@@ -637,9 +638,9 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=Firstworks::SQLRConnection->new($ARGV[0],
+$secondcon=SQLRelay::Connection->new($ARGV[0],
 			$ARGV[1],$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$secondcur=Firstworks::SQLRCursor->new($secondcon);
+$secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"0");
 checkSuccess($con->commit(),1);
