@@ -54,7 +54,7 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("AFFECTED ROWS: \n");
-	checkSuccess(sqlrcur_affectedRows($cur),-1);
+	checkSuccess(sqlrcur_affectedRows($cur),1);
 	echo("\n");
 
 	echo("BIND BY POSITION: \n");
@@ -280,14 +280,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getLongest($cur,"testtinyint"),1);
 	checkSuccess(sqlrcur_getLongest($cur,3),3);
 	checkSuccess(sqlrcur_getLongest($cur,"testreal"),3);
-	checkSuccess(sqlrcur_getLongest($cur,4),3);
-	checkSuccess(sqlrcur_getLongest($cur,"testfloat"),3);
-	checkSuccess(sqlrcur_getLongest($cur,5),3);
-	checkSuccess(sqlrcur_getLongest($cur,"testdecimal"),3);
-	checkSuccess(sqlrcur_getLongest($cur,6),3);
-	checkSuccess(sqlrcur_getLongest($cur,"testnumeric"),3);
-	checkSuccess(sqlrcur_getLongest($cur,7),6);
-	checkSuccess(sqlrcur_getLongest($cur,"testmoney"),6);
+	checkSuccess(sqlrcur_getLongest($cur,4),17);
+	checkSuccess(sqlrcur_getLongest($cur,"testfloat"),17);
+	checkSuccess(sqlrcur_getLongest($cur,5),17);
+	checkSuccess(sqlrcur_getLongest($cur,"testdecimal"),17);
+	checkSuccess(sqlrcur_getLongest($cur,6),17);
+	checkSuccess(sqlrcur_getLongest($cur,"testnumeric"),17);
+	checkSuccess(sqlrcur_getLongest($cur,7),4);
+	checkSuccess(sqlrcur_getLongest($cur,"testmoney"),4);
 	checkSuccess(sqlrcur_getLongest($cur,8),4);
 	checkSuccess(sqlrcur_getLongest($cur,"testsmallmoney"),4);
 	checkSuccess(sqlrcur_getLongest($cur,9),19);
@@ -307,7 +307,7 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("TOTAL ROWS: \n");
-	checkSuccess(sqlrcur_totalRows($cur),-1);
+	checkSuccess(sqlrcur_totalRows($cur),0);
 	echo("\n");
 
 	echo("FIRST ROW INDEX: \n");
@@ -326,10 +326,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getField($cur,0,4),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,5),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,6),"1.1");
-	checkSuccess(sqlrcur_getField($cur,0,7),"1.0000");
+	checkSuccess(sqlrcur_getField($cur,0,7),"1.00");
 	checkSuccess(sqlrcur_getField($cur,0,8),"1.00");
-	checkSuccess(sqlrcur_getField($cur,0,9),"Jan  1 2001  1:00AM");
-	checkSuccess(sqlrcur_getField($cur,0,10),"Jan  1 2001  1:00AM");
+	checkSuccess(sqlrcur_getField($cur,0,9),"Jan 01 2001 01:00AM");
+	checkSuccess(sqlrcur_getField($cur,0,10),"Jan 01 2001 01:00AM");
 	checkSuccess(sqlrcur_getField($cur,0,11),"testchar1                               ");
 	checkSuccess(sqlrcur_getField($cur,0,12),"testvarchar1");
 	checkSuccess(sqlrcur_getField($cur,0,13),"1");
@@ -341,10 +341,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getField($cur,7,4),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,5),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,6),"8.8");
-	checkSuccess(sqlrcur_getField($cur,7,7),"8.0000");
+	checkSuccess(sqlrcur_getField($cur,7,7),"8.00");
 	checkSuccess(sqlrcur_getField($cur,7,8),"8.00");
-	checkSuccess(sqlrcur_getField($cur,7,9),"Jan  1 2008  8:00AM");
-	checkSuccess(sqlrcur_getField($cur,7,10),"Jan  1 2008  8:00AM");
+	checkSuccess(sqlrcur_getField($cur,7,9),"Jan 01 2008 08:00AM");
+	checkSuccess(sqlrcur_getField($cur,7,10),"Jan 01 2008 08:00AM");
 	checkSuccess(sqlrcur_getField($cur,7,11),"testchar8                               ");
 	checkSuccess(sqlrcur_getField($cur,7,12),"testvarchar8");
 	checkSuccess(sqlrcur_getField($cur,7,13),"1");
@@ -358,7 +358,7 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getFieldLength($cur,0,4),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,5),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,6),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,7),6);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,7),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,8),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,9),19);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,10),19);
@@ -370,10 +370,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getFieldLength($cur,7,1),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,2),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,3),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,4),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,5),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,6),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,7),6);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,4),17);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,5),17);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,6),17);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,7),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,8),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,9),19);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,10),19);
@@ -390,10 +390,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getField($cur,0,"testfloat"),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,"testdecimal"),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,"testnumeric"),"1.1");
-	checkSuccess(sqlrcur_getField($cur,0,"testmoney"),"1.0000");
+	checkSuccess(sqlrcur_getField($cur,0,"testmoney"),"1.00");
 	checkSuccess(sqlrcur_getField($cur,0,"testsmallmoney"),"1.00");
-	checkSuccess(sqlrcur_getField($cur,0,"testdatetime"),"Jan  1 2001  1:00AM");
-	checkSuccess(sqlrcur_getField($cur,0,"testsmalldatetime"),"Jan  1 2001  1:00AM");
+	checkSuccess(sqlrcur_getField($cur,0,"testdatetime"),"Jan 01 2001 01:00AM");
+	checkSuccess(sqlrcur_getField($cur,0,"testsmalldatetime"),"Jan 01 2001 01:00AM");
 	checkSuccess(sqlrcur_getField($cur,0,"testchar"),"testchar1                               ");
 	checkSuccess(sqlrcur_getField($cur,0,"testvarchar"),"testvarchar1");
 	checkSuccess(sqlrcur_getField($cur,0,"testbit"),"1");
@@ -405,10 +405,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getField($cur,7,"testfloat"),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,"testdecimal"),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,"testnumeric"),"8.8");
-	checkSuccess(sqlrcur_getField($cur,7,"testmoney"),"8.0000");
+	checkSuccess(sqlrcur_getField($cur,7,"testmoney"),"8.00");
 	checkSuccess(sqlrcur_getField($cur,7,"testsmallmoney"),"8.00");
-	checkSuccess(sqlrcur_getField($cur,7,"testdatetime"),"Jan  1 2008  8:00AM");
-	checkSuccess(sqlrcur_getField($cur,7,"testsmalldatetime"),"Jan  1 2008  8:00AM");
+	checkSuccess(sqlrcur_getField($cur,7,"testdatetime"),"Jan 01 2008 08:00AM");
+	checkSuccess(sqlrcur_getField($cur,7,"testsmalldatetime"),"Jan 01 2008 08:00AM");
 	checkSuccess(sqlrcur_getField($cur,7,"testchar"),"testchar8                               ");
 	checkSuccess(sqlrcur_getField($cur,7,"testvarchar"),"testvarchar8");
 	checkSuccess(sqlrcur_getField($cur,7,"testbit"),"1");
@@ -422,7 +422,7 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testfloat"),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdecimal"),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testnumeric"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testmoney"),6);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"testmoney"),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testsmallmoney"),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdatetime"),19);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testsmalldatetime"),19);
@@ -434,10 +434,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmallint"),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testtinyint"),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testreal"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testfloat"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdecimal"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testnumeric"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testmoney"),6);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"testfloat"),17);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdecimal"),17);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"testnumeric"),17);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"testmoney"),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmallmoney"),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdatetime"),19);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmalldatetime"),19);
@@ -455,10 +455,10 @@ function checkSuccess($value,$success) {
 	checkSuccess($fields[4],"1.1");
 	checkSuccess($fields[5],"1.1");
 	checkSuccess($fields[6],"1.1");
-	checkSuccess($fields[7],"1.0000");
+	checkSuccess($fields[7],"1.00");
 	checkSuccess($fields[8],"1.00");
-	checkSuccess($fields[9],"Jan  1 2001  1:00AM");
-	checkSuccess($fields[10],"Jan  1 2001  1:00AM");
+	checkSuccess($fields[9],"Jan 01 2001 01:00AM");
+	checkSuccess($fields[10],"Jan 01 2001 01:00AM");
 	checkSuccess($fields[11],"testchar1                               ");
 	checkSuccess($fields[12],"testvarchar1");
 	checkSuccess($fields[13],"1");
@@ -473,7 +473,7 @@ function checkSuccess($value,$success) {
 	checkSuccess($fieldlens[4],3);
 	checkSuccess($fieldlens[5],3);
 	checkSuccess($fieldlens[6],3);
-	checkSuccess($fieldlens[7],6);
+	checkSuccess($fieldlens[7],4);
 	checkSuccess($fieldlens[8],4);
 	checkSuccess($fieldlens[9],19);
 	checkSuccess($fieldlens[10],19);
@@ -493,10 +493,10 @@ function checkSuccess($value,$success) {
 	checkSuccess($fields["testfloat"],"1.1");
 	checkSuccess($fields["testdecimal"],"1.1");
 	checkSuccess($fields["testnumeric"],"1.1");
-	checkSuccess($fields["testmoney"],"1.0000");
+	checkSuccess($fields["testmoney"],"1.00");
 	checkSuccess($fields["testsmallmoney"],"1.00");
-	checkSuccess($fields["testdatetime"],"Jan  1 2001  1:00AM");
-	checkSuccess($fields["testsmalldatetime"],"Jan  1 2001  1:00AM");
+	checkSuccess($fields["testdatetime"],"Jan 01 2001 01:00AM");
+	checkSuccess($fields["testsmalldatetime"],"Jan 01 2001 01:00AM");
 	checkSuccess($fields["testchar"],"testchar1                               ");
 	checkSuccess($fields["testvarchar"],"testvarchar1");
 	checkSuccess($fields["testbit"],"1");
@@ -509,10 +509,10 @@ function checkSuccess($value,$success) {
 	checkSuccess($fields["testfloat"],"8.8");
 	checkSuccess($fields["testdecimal"],"8.8");
 	checkSuccess($fields["testnumeric"],"8.8");
-	checkSuccess($fields["testmoney"],"8.0000");
+	checkSuccess($fields["testmoney"],"8.00");
 	checkSuccess($fields["testsmallmoney"],"8.00");
-	checkSuccess($fields["testdatetime"],"Jan  1 2008  8:00AM");
-	checkSuccess($fields["testsmalldatetime"],"Jan  1 2008  8:00AM");
+	checkSuccess($fields["testdatetime"],"Jan 01 2008 08:00AM");
+	checkSuccess($fields["testsmalldatetime"],"Jan 01 2008 08:00AM");
 	checkSuccess($fields["testchar"],"testchar8                               ");
 	checkSuccess($fields["testvarchar"],"testvarchar8");
 	checkSuccess($fields["testbit"],"1");
@@ -527,7 +527,7 @@ function checkSuccess($value,$success) {
 	checkSuccess($fieldlengths["testfloat"],3);
 	checkSuccess($fieldlengths["testdecimal"],3);
 	checkSuccess($fieldlengths["testnumeric"],3);
-	checkSuccess($fieldlengths["testmoney"],6);
+	checkSuccess($fieldlengths["testmoney"],4);
 	checkSuccess($fieldlengths["testsmallmoney"],4);
 	checkSuccess($fieldlengths["testdatetime"],19);
 	checkSuccess($fieldlengths["testsmalldatetime"],19);
@@ -540,10 +540,10 @@ function checkSuccess($value,$success) {
 	checkSuccess($fieldlengths["testsmallint"],1);
 	checkSuccess($fieldlengths["testtinyint"],1);
 	checkSuccess($fieldlengths["testreal"],3);
-	checkSuccess($fieldlengths["testfloat"],3);
-	checkSuccess($fieldlengths["testdecimal"],3);
-	checkSuccess($fieldlengths["testnumeric"],3);
-	checkSuccess($fieldlengths["testmoney"],6);
+	checkSuccess($fieldlengths["testfloat"],17);
+	checkSuccess($fieldlengths["testdecimal"],17);
+	checkSuccess($fieldlengths["testnumeric"],17);
+	checkSuccess($fieldlengths["testmoney"],4);
 	checkSuccess($fieldlengths["testsmallmoney"],4);
 	checkSuccess($fieldlengths["testdatetime"],19);
 	checkSuccess($fieldlengths["testsmalldatetime"],19);
