@@ -131,46 +131,46 @@ function checkSuccess($value,$success) {
 
 	echo("OUTPUT BIND BY NAME: \n");
 	sqlrcur_prepareQuery($cur,"begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;");
-	sqlrcur_defineOutputBind($cur,"numvar",10);
-	sqlrcur_defineOutputBind($cur,"stringvar",10);
-	sqlrcur_defineOutputBind($cur,"floatvar",10);
+	sqlrcur_defineOutputBindInteger($cur,"numvar");
+	sqlrcur_defineOutputBindString($cur,"stringvar",10);
+	sqlrcur_defineOutputBindDouble($cur,"floatvar");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	$numvar=sqlrcur_getOutputBind($cur,"numvar");
-	$stringvar=sqlrcur_getOutputBind($cur,"stringvar");
-	$floatvar=sqlrcur_getOutputBind($cur,"floatvar");
-	checkSuccess($numvar,"1");
+	$numvar=sqlrcur_getOutputBindInteger($cur,"numvar");
+	$stringvar=sqlrcur_getOutputBindString($cur,"stringvar");
+	$floatvar=sqlrcur_getOutputBindDouble($cur,"floatvar");
+	checkSuccess($numvar,1);
 	checkSuccess($stringvar,"hello");
-	checkSuccess($floatvar,"2.5");
+	checkSuccess($floatvar,2.5);
 	echo("\n");
 
 	echo("OUTPUT BIND BY NAME: \n");
 	sqlrcur_clearBinds($cur);
-	sqlrcur_defineOutputBind($cur,"1",10);
-	sqlrcur_defineOutputBind($cur,"2",10);
-	sqlrcur_defineOutputBind($cur,"3",10);
+	sqlrcur_defineOutputBindInteger($cur,"1");
+	sqlrcur_defineOutputBindString($cur,"2",10);
+	sqlrcur_defineOutputBindDouble($cur,"3");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	$numvar=sqlrcur_getOutputBind($cur,"1");
-	$stringvar=sqlrcur_getOutputBind($cur,"2");
-	$floatvar=sqlrcur_getOutputBind($cur,"3");
-	checkSuccess($numvar,"1");
+	$numvar=sqlrcur_getOutputBindInteger($cur,"1");
+	$stringvar=sqlrcur_getOutputBindString($cur,"2");
+	$floatvar=sqlrcur_getOutputBindDouble($cur,"3");
+	checkSuccess($numvar,1);
 	checkSuccess($stringvar,"hello");
-	checkSuccess($floatvar,"2.5");
+	checkSuccess($floatvar,2.5);
 	echo("\n");
 
 	echo("OUTPUT BIND BY NAME WITH VALIDATION: \n");
 	sqlrcur_clearBinds($cur);
-	sqlrcur_defineOutputBind($cur,"numvar",10);
-	sqlrcur_defineOutputBind($cur,"stringvar",10);
-	sqlrcur_defineOutputBind($cur,"floatvar",10);
-	sqlrcur_defineOutputBind($cur,"dummyvar",10);
+	sqlrcur_defineOutputBindInteger($cur,"numvar");
+	sqlrcur_defineOutputBindString($cur,"stringvar",10);
+	sqlrcur_defineOutputBindDouble($cur,"floatvar");
+	sqlrcur_defineOutputBindString($cur,"dummyvar",10);
 	sqlrcur_validateBinds($cur);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	$numvar=sqlrcur_getOutputBind($cur,"numvar");
-	$stringvar=sqlrcur_getOutputBind($cur,"stringvar");
-	$floatvar=sqlrcur_getOutputBind($cur,"floatvar");
-	checkSuccess($numvar,"1");
+	$numvar=sqlrcur_getOutputBindInteger($cur,"numvar");
+	$stringvar=sqlrcur_getOutputBindString($cur,"stringvar");
+	$floatvar=sqlrcur_getOutputBindDouble($cur,"floatvar");
+	checkSuccess($numvar,1);
 	checkSuccess($stringvar,"hello");
-	checkSuccess($floatvar,"2.5");
+	checkSuccess($floatvar,2.5);
 	echo("\n");
 
 	echo("SELECT: \n");
@@ -255,7 +255,7 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("TOTAL ROWS: \n");
-	checkSuccess(sqlrcur_totalRows($cur),-1);
+	checkSuccess(sqlrcur_totalRows($cur),0);
 	echo("\n");
 
 	echo("FIRST ROW INDEX: \n");
@@ -416,9 +416,9 @@ function checkSuccess($value,$success) {
 
 	echo("OUTPUT BIND: \n");
 	sqlrcur_prepareQuery($cur,"begin :var1:='hello'; end;");
-	sqlrcur_defineOutputBind($cur,"var1",10);
+	sqlrcur_defineOutputBindString($cur,"var1",10);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	checkSuccess(sqlrcur_getOutputBind($cur,"var1"),"hello");
+	checkSuccess(sqlrcur_getOutputBindString($cur,"var1"),"hello");
 	echo("\n");
 
 	echo("ARRAY SUBSTITUTIONS: \n");
@@ -702,9 +702,9 @@ function checkSuccess($value,$success) {
 	sqlrcur_defineOutputBindClob($cur,"clobvar");
 	sqlrcur_defineOutputBindBlob($cur,"blobvar");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	$clobvar=sqlrcur_getOutputBind($cur,"clobvar");
+	$clobvar=sqlrcur_getOutputBindClob($cur,"clobvar");
 	$clobvarlength=sqlrcur_getOutputBindLength($cur,"clobvar");
-	$blobvar=sqlrcur_getOutputBind($cur,"blobvar");
+	$blobvar=sqlrcur_getOutputBindBlob($cur,"blobvar");
 	$blobvarlength=sqlrcur_getOutputBindLength($cur,"blobvar");
 	checkSuccess($clobvar,"hello");
 	checkSuccess($clobvarlength,5);
@@ -764,7 +764,7 @@ function checkSuccess($value,$success) {
 	sqlrcur_prepareQuery($cur,"begin select testclob into :clobbindval from testtable2; end;");
 	sqlrcur_defineOutputBindClob($cur,"clobbindval");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	$clobbindvar=sqlrcur_getOutputBind($cur,"clobbindval");
+	$clobbindvar=sqlrcur_getOutputBindClob($cur,"clobbindval");
 	checkSuccess(sqlrcur_getOutputBindLength($cur,"clobbindval"),8*1024);
 	checkSuccess($clobval,$clobbindvar);
 	sqlrcur_sendQuery($cur,"drop table testtable2");
@@ -785,10 +785,10 @@ function checkSuccess($value,$success) {
 	checkSuccess($testval,sqlrcur_getField($cur,0,"testval"));
 	$query="begin :bindval:='".$testval."'; end;";
 	sqlrcur_prepareQuery($cur,$query);
-	sqlrcur_defineOutputBind($cur,"bindval",4000);
+	sqlrcur_defineOutputBindString($cur,"bindval",4000);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 	checkSuccess(sqlrcur_getOutputBindLength($cur,"bindval"),4000);
-	checkSuccess(sqlrcur_getOutputBind($cur,"bindval"),$testval);
+	checkSuccess(sqlrcur_getOutputBindString($cur,"bindval"),$testval);
 	sqlrcur_sendQuery($cur,"drop table testtable2");
 	echo("\n");
 
