@@ -247,10 +247,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getColumnType($cur,"testdatetime"),"DATETIME");
 	checkSuccess(sqlrcur_getColumnType($cur,10),"SMALLDATETIME");
 	checkSuccess(sqlrcur_getColumnType($cur,"testsmalldatetime"),"SMALLDATETIME");
-	checkSuccess(sqlrcur_getColumnType($cur,11),"CHAR");
-	checkSuccess(sqlrcur_getColumnType($cur,"testchar"),"CHAR");
-	checkSuccess(sqlrcur_getColumnType($cur,12),"CHAR");
-	checkSuccess(sqlrcur_getColumnType($cur,"testvarchar"),"CHAR");
+	checkSuccess(sqlrcur_getColumnType($cur,11),"LONGCHAR");
+	checkSuccess(sqlrcur_getColumnType($cur,"testchar"),"LONGCHAR");
+	checkSuccess(sqlrcur_getColumnType($cur,12),"LONGCHAR");
+	checkSuccess(sqlrcur_getColumnType($cur,"testvarchar"),"LONGCHAR");
 	checkSuccess(sqlrcur_getColumnType($cur,13),"BIT");
 	checkSuccess(sqlrcur_getColumnType($cur,"testbit"),"BIT");
 	echo("\n");
@@ -278,10 +278,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getColumnLength($cur,"testdatetime"),8);
 	checkSuccess(sqlrcur_getColumnLength($cur,10),4);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testsmalldatetime"),4);
-	checkSuccess(sqlrcur_getColumnLength($cur,11),40);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testchar"),40);
-	checkSuccess(sqlrcur_getColumnLength($cur,12),40);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testvarchar"),40);
+	checkSuccess(sqlrcur_getColumnLength($cur,11),80);
+	checkSuccess(sqlrcur_getColumnLength($cur,"testchar"),80);
+	checkSuccess(sqlrcur_getColumnLength($cur,12),80);
+	checkSuccess(sqlrcur_getColumnLength($cur,"testvarchar"),80);
 	checkSuccess(sqlrcur_getColumnLength($cur,13),1);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testbit"),1);
 	echo("\n");
