@@ -222,7 +222,7 @@ def main():
 	print
 
 	print "TOTAL ROWS: "
-	checkSuccess(cur.totalRows(),-1)
+	checkSuccess(cur.totalRows(),0)
 	print
 
 	print "FIRST ROW INDEX: "
