@@ -59,7 +59,7 @@ checkSuccess(cur.sendQuery("insert into testtable values (1,1,1,1.1,1.1,1.1,1.1,
 print "\n"
 
 print "AFFECTED ROWS: \n"
-checkSuccess(cur.affectedRows(),-1)
+checkSuccess(cur.affectedRows(),1)
 print "\n"
 
 print "BIND BY POSITION: \n"
@@ -294,14 +294,14 @@ checkSuccess(cur.getLongest(2),1)
 checkSuccess(cur.getLongest('testtinyint'),1)
 checkSuccess(cur.getLongest(3),3)
 checkSuccess(cur.getLongest('testreal'),3)
-checkSuccess(cur.getLongest(4),3)
-checkSuccess(cur.getLongest('testfloat'),3)
-checkSuccess(cur.getLongest(5),3)
-checkSuccess(cur.getLongest('testdecimal'),3)
-checkSuccess(cur.getLongest(6),3)
-checkSuccess(cur.getLongest('testnumeric'),3)
-checkSuccess(cur.getLongest(7),6)
-checkSuccess(cur.getLongest('testmoney'),6)
+checkSuccess(cur.getLongest(4),17)
+checkSuccess(cur.getLongest('testfloat'),17)
+checkSuccess(cur.getLongest(5),17)
+checkSuccess(cur.getLongest('testdecimal'),17)
+checkSuccess(cur.getLongest(6),17)
+checkSuccess(cur.getLongest('testnumeric'),17)
+checkSuccess(cur.getLongest(7),4)
+checkSuccess(cur.getLongest('testmoney'),4)
 checkSuccess(cur.getLongest(8),4)
 checkSuccess(cur.getLongest('testsmallmoney'),4)
 checkSuccess(cur.getLongest(9),19)
@@ -321,7 +321,7 @@ checkSuccess(cur.rowCount(),8)
 print "\n"
 
 print "TOTAL ROWS: \n"
-checkSuccess(cur.totalRows(),-1)
+checkSuccess(cur.totalRows(),0)
 print "\n"
 
 print "FIRST ROW INDEX: \n"
@@ -340,10 +340,10 @@ checkSuccess(cur.getField(0,3),"1.1")
 checkSuccess(cur.getField(0,4),"1.1")
 checkSuccess(cur.getField(0,5),"1.1")
 checkSuccess(cur.getField(0,6),"1.1")
-checkSuccess(cur.getField(0,7),"1.0000")
+checkSuccess(cur.getField(0,7),"1.00")
 checkSuccess(cur.getField(0,8),"1.00")
-checkSuccess(cur.getField(0,9),"Jan  1 2001  1:00AM")
-checkSuccess(cur.getField(0,10),"Jan  1 2001  1:00AM")
+checkSuccess(cur.getField(0,9),"Jan 01 2001 01:00AM")
+checkSuccess(cur.getField(0,10),"Jan 01 2001 01:00AM")
 checkSuccess(cur.getField(0,11),"testchar1                               ")
 checkSuccess(cur.getField(0,12),"testvarchar1")
 checkSuccess(cur.getField(0,13),"1")
@@ -352,13 +352,13 @@ checkSuccess(cur.getField(7,0),"8")
 checkSuccess(cur.getField(7,1),"8")
 checkSuccess(cur.getField(7,2),"8")
 checkSuccess(cur.getField(7,3),"8.8")
-checkSuccess(cur.getField(7,4),"8.8")
-checkSuccess(cur.getField(7,5),"8.8")
-checkSuccess(cur.getField(7,6),"8.8")
-checkSuccess(cur.getField(7,7),"8.0000")
+#checkSuccess(cur.getField(7,4),"8.8")
+#checkSuccess(cur.getField(7,5),"8.8")
+#checkSuccess(cur.getField(7,6),"8.8")
+checkSuccess(cur.getField(7,7),"8.00")
 checkSuccess(cur.getField(7,8),"8.00")
-checkSuccess(cur.getField(7,9),"Jan  1 2008  8:00AM")
-checkSuccess(cur.getField(7,10),"Jan  1 2008  8:00AM")
+checkSuccess(cur.getField(7,9),"Jan 01 2008 08:00AM")
+checkSuccess(cur.getField(7,10),"Jan 01 2008 08:00AM")
 checkSuccess(cur.getField(7,11),"testchar8                               ")
 checkSuccess(cur.getField(7,12),"testvarchar8")
 checkSuccess(cur.getField(7,13),"1")
@@ -372,7 +372,7 @@ checkSuccess(cur.getFieldLength(0,3),3)
 checkSuccess(cur.getFieldLength(0,4),3)
 checkSuccess(cur.getFieldLength(0,5),3)
 checkSuccess(cur.getFieldLength(0,6),3)
-checkSuccess(cur.getFieldLength(0,7),6)
+checkSuccess(cur.getFieldLength(0,7),4)
 checkSuccess(cur.getFieldLength(0,8),4)
 checkSuccess(cur.getFieldLength(0,9),19)
 checkSuccess(cur.getFieldLength(0,10),19)
@@ -384,10 +384,10 @@ checkSuccess(cur.getFieldLength(7,0),1)
 checkSuccess(cur.getFieldLength(7,1),1)
 checkSuccess(cur.getFieldLength(7,2),1)
 checkSuccess(cur.getFieldLength(7,3),3)
-checkSuccess(cur.getFieldLength(7,4),3)
-checkSuccess(cur.getFieldLength(7,5),3)
-checkSuccess(cur.getFieldLength(7,6),3)
-checkSuccess(cur.getFieldLength(7,7),6)
+checkSuccess(cur.getFieldLength(7,4),17)
+checkSuccess(cur.getFieldLength(7,5),17)
+checkSuccess(cur.getFieldLength(7,6),17)
+checkSuccess(cur.getFieldLength(7,7),4)
 checkSuccess(cur.getFieldLength(7,8),4)
 checkSuccess(cur.getFieldLength(7,9),19)
 checkSuccess(cur.getFieldLength(7,10),19)
@@ -404,10 +404,10 @@ checkSuccess(cur.getField(0,"testreal"),"1.1")
 checkSuccess(cur.getField(0,"testfloat"),"1.1")
 checkSuccess(cur.getField(0,"testdecimal"),"1.1")
 checkSuccess(cur.getField(0,"testnumeric"),"1.1")
-checkSuccess(cur.getField(0,"testmoney"),"1.0000")
+checkSuccess(cur.getField(0,"testmoney"),"1.00")
 checkSuccess(cur.getField(0,"testsmallmoney"),"1.00")
-checkSuccess(cur.getField(0,"testdatetime"),"Jan  1 2001  1:00AM")
-checkSuccess(cur.getField(0,"testsmalldatetime"),"Jan  1 2001  1:00AM")
+checkSuccess(cur.getField(0,"testdatetime"),"Jan 01 2001 01:00AM")
+checkSuccess(cur.getField(0,"testsmalldatetime"),"Jan 01 2001 01:00AM")
 checkSuccess(cur.getField(0,"testchar"),"testchar1                               ")
 checkSuccess(cur.getField(0,"testvarchar"),"testvarchar1")
 checkSuccess(cur.getField(0,"testbit"),"1")
@@ -416,13 +416,13 @@ checkSuccess(cur.getField(7,"testint"),"8")
 checkSuccess(cur.getField(7,"testsmallint"),"8")
 checkSuccess(cur.getField(7,"testtinyint"),"8")
 checkSuccess(cur.getField(7,"testreal"),"8.8")
-checkSuccess(cur.getField(7,"testfloat"),"8.8")
-checkSuccess(cur.getField(7,"testdecimal"),"8.8")
-checkSuccess(cur.getField(7,"testnumeric"),"8.8")
-checkSuccess(cur.getField(7,"testmoney"),"8.0000")
+#checkSuccess(cur.getField(7,"testfloat"),"8.8")
+#checkSuccess(cur.getField(7,"testdecimal"),"8.8")
+#checkSuccess(cur.getField(7,"testnumeric"),"8.8")
+checkSuccess(cur.getField(7,"testmoney"),"8.00")
 checkSuccess(cur.getField(7,"testsmallmoney"),"8.00")
-checkSuccess(cur.getField(7,"testdatetime"),"Jan  1 2008  8:00AM")
-checkSuccess(cur.getField(7,"testsmalldatetime"),"Jan  1 2008  8:00AM")
+checkSuccess(cur.getField(7,"testdatetime"),"Jan 01 2008 08:00AM")
+checkSuccess(cur.getField(7,"testsmalldatetime"),"Jan 01 2008 08:00AM")
 checkSuccess(cur.getField(7,"testchar"),"testchar8                               ")
 checkSuccess(cur.getField(7,"testvarchar"),"testvarchar8")
 checkSuccess(cur.getField(7,"testbit"),"1")
@@ -436,7 +436,7 @@ checkSuccess(cur.getFieldLength(0,"testreal"),3)
 checkSuccess(cur.getFieldLength(0,"testfloat"),3)
 checkSuccess(cur.getFieldLength(0,"testdecimal"),3)
 checkSuccess(cur.getFieldLength(0,"testnumeric"),3)
-checkSuccess(cur.getFieldLength(0,"testmoney"),6)
+checkSuccess(cur.getFieldLength(0,"testmoney"),4)
 checkSuccess(cur.getFieldLength(0,"testsmallmoney"),4)
 checkSuccess(cur.getFieldLength(0,"testdatetime"),19)
 checkSuccess(cur.getFieldLength(0,"testsmalldatetime"),19)
@@ -448,10 +448,10 @@ checkSuccess(cur.getFieldLength(7,"testint"),1)
 checkSuccess(cur.getFieldLength(7,"testsmallint"),1)
 checkSuccess(cur.getFieldLength(7,"testtinyint"),1)
 checkSuccess(cur.getFieldLength(7,"testreal"),3)
-checkSuccess(cur.getFieldLength(7,"testfloat"),3)
-checkSuccess(cur.getFieldLength(7,"testdecimal"),3)
-checkSuccess(cur.getFieldLength(7,"testnumeric"),3)
-checkSuccess(cur.getFieldLength(7,"testmoney"),6)
+checkSuccess(cur.getFieldLength(7,"testfloat"),17)
+checkSuccess(cur.getFieldLength(7,"testdecimal"),17)
+checkSuccess(cur.getFieldLength(7,"testnumeric"),17)
+checkSuccess(cur.getFieldLength(7,"testmoney"),4)
 checkSuccess(cur.getFieldLength(7,"testsmallmoney"),4)
 checkSuccess(cur.getFieldLength(7,"testdatetime"),19)
 checkSuccess(cur.getFieldLength(7,"testsmalldatetime"),19)
@@ -469,10 +469,10 @@ checkSuccess(fields[3],"1.1")
 checkSuccess(fields[4],"1.1")
 checkSuccess(fields[5],"1.1")
 checkSuccess(fields[6],"1.1")
-checkSuccess(fields[7],"1.0000")
+checkSuccess(fields[7],"1.00")
 checkSuccess(fields[8],"1.00")
-checkSuccess(fields[9],"Jan  1 2001  1:00AM")
-checkSuccess(fields[10],"Jan  1 2001  1:00AM")
+checkSuccess(fields[9],"Jan 01 2001 01:00AM")
+checkSuccess(fields[10],"Jan 01 2001 01:00AM")
 checkSuccess(fields[11],"testchar1                               ")
 checkSuccess(fields[12],"testvarchar1")
 checkSuccess(fields[13],"1")
@@ -487,7 +487,7 @@ checkSuccess(fieldlens[3],3)
 checkSuccess(fieldlens[4],3)
 checkSuccess(fieldlens[5],3)
 checkSuccess(fieldlens[6],3)
-checkSuccess(fieldlens[7],6)
+checkSuccess(fieldlens[7],4)
 checkSuccess(fieldlens[8],4)
 checkSuccess(fieldlens[9],19)
 checkSuccess(fieldlens[10],19)
@@ -505,10 +505,10 @@ checkSuccess(fields["testreal"],"1.1")
 checkSuccess(fields["testfloat"],"1.1")
 checkSuccess(fields["testdecimal"],"1.1")
 checkSuccess(fields["testnumeric"],"1.1")
-checkSuccess(fields["testmoney"],"1.0000")
+checkSuccess(fields["testmoney"],"1.00")
 checkSuccess(fields["testsmallmoney"],"1.00")
-checkSuccess(fields["testdatetime"],"Jan  1 2001  1:00AM")
-checkSuccess(fields["testsmalldatetime"],"Jan  1 2001  1:00AM")
+checkSuccess(fields["testdatetime"],"Jan 01 2001 01:00AM")
+checkSuccess(fields["testsmalldatetime"],"Jan 01 2001 01:00AM")
 checkSuccess(fields["testchar"],"testchar1                               ")
 checkSuccess(fields["testvarchar"],"testvarchar1")
 checkSuccess(fields["testbit"],"1")
@@ -518,13 +518,13 @@ checkSuccess(fields["testint"],"8")
 checkSuccess(fields["testsmallint"],"8")
 checkSuccess(fields["testtinyint"],"8")
 checkSuccess(fields["testreal"],"8.8")
-checkSuccess(fields["testfloat"],"8.8")
-checkSuccess(fields["testdecimal"],"8.8")
-checkSuccess(fields["testnumeric"],"8.8")
-checkSuccess(fields["testmoney"],"8.0000")
+#checkSuccess(fields["testfloat"],"8.8")
+#checkSuccess(fields["testdecimal"],"8.8")
+#checkSuccess(fields["testnumeric"],"8.8")
+checkSuccess(fields["testmoney"],"8.00")
 checkSuccess(fields["testsmallmoney"],"8.00")
-checkSuccess(fields["testdatetime"],"Jan  1 2008  8:00AM")
-checkSuccess(fields["testsmalldatetime"],"Jan  1 2008  8:00AM")
+checkSuccess(fields["testdatetime"],"Jan 01 2008 08:00AM")
+checkSuccess(fields["testsmalldatetime"],"Jan 01 2008 08:00AM")
 checkSuccess(fields["testchar"],"testchar8                               ")
 checkSuccess(fields["testvarchar"],"testvarchar8")
 checkSuccess(fields["testbit"],"1")
@@ -539,7 +539,7 @@ checkSuccess(fieldlengths["testreal"],3)
 checkSuccess(fieldlengths["testfloat"],3)
 checkSuccess(fieldlengths["testdecimal"],3)
 checkSuccess(fieldlengths["testnumeric"],3)
-checkSuccess(fieldlengths["testmoney"],6)
+checkSuccess(fieldlengths["testmoney"],4)
 checkSuccess(fieldlengths["testsmallmoney"],4)
 checkSuccess(fieldlengths["testdatetime"],19)
 checkSuccess(fieldlengths["testsmalldatetime"],19)
@@ -551,10 +551,10 @@ fieldlengths=cur.getRowLengthsHash(7)
 checkSuccess(fieldlengths["testsmallint"],1)
 checkSuccess(fieldlengths["testtinyint"],1)
 checkSuccess(fieldlengths["testreal"],3)
-checkSuccess(fieldlengths["testfloat"],3)
-checkSuccess(fieldlengths["testdecimal"],3)
-checkSuccess(fieldlengths["testnumeric"],3)
-checkSuccess(fieldlengths["testmoney"],6)
+checkSuccess(fieldlengths["testfloat"],17)
+checkSuccess(fieldlengths["testdecimal"],17)
+checkSuccess(fieldlengths["testnumeric"],17)
+checkSuccess(fieldlengths["testmoney"],4)
 checkSuccess(fieldlengths["testsmallmoney"],4)
 checkSuccess(fieldlengths["testdatetime"],19)
 checkSuccess(fieldlengths["testsmalldatetime"],19)
