@@ -60,7 +60,7 @@ checkSuccess(cur.sendQuery("insert into testtable values (4,4.4,'testchar4','tes
 print "\n"
 
 print "AFFECTED ROWS: \n"
-checkSuccess(cur.affectedRows(),-1)
+checkSuccess(cur.affectedRows(),0)
 print "\n"
 
 print "BIND BY NAME: \n"
@@ -529,7 +529,8 @@ secondcon=SQLRConnection.new(ARGV[0],
 			ARGV[1].to_i, 
 			ARGV[2],ARGV[3],ARGV[4],0,1)
 secondcur=SQLRCursor.new(secondcon)
-checkSuccess(secondcur.sendQuery("select count(*) from testtable"),0)
+checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
+checkSuccess(secondcur.getField(0,0),"0")
 checkSuccess(con.commit(),1)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
 checkSuccess(secondcur.getField(0,0),"8")
