@@ -243,10 +243,10 @@ checkSuccess(cur.getColumnType(9),"DATETIME")
 checkSuccess(cur.getColumnType('testdatetime'),"DATETIME")
 checkSuccess(cur.getColumnType(10),"SMALLDATETIME")
 checkSuccess(cur.getColumnType('testsmalldatetime'),"SMALLDATETIME")
-checkSuccess(cur.getColumnType(11),"CHAR")
-checkSuccess(cur.getColumnType('testchar'),"CHAR")
-checkSuccess(cur.getColumnType(12),"CHAR")
-checkSuccess(cur.getColumnType('testvarchar'),"CHAR")
+checkSuccess(cur.getColumnType(11),"LONGCHAR")
+checkSuccess(cur.getColumnType('testchar'),"LONGCHAR")
+checkSuccess(cur.getColumnType(12),"LONGCHAR")
+checkSuccess(cur.getColumnType('testvarchar'),"LONGCHAR")
 checkSuccess(cur.getColumnType(13),"BIT")
 checkSuccess(cur.getColumnType('testbit'),"BIT")
 print "\n"
@@ -274,10 +274,10 @@ checkSuccess(cur.getColumnLength(9),8)
 checkSuccess(cur.getColumnLength('testdatetime'),8)
 checkSuccess(cur.getColumnLength(10),4)
 checkSuccess(cur.getColumnLength('testsmalldatetime'),4)
-checkSuccess(cur.getColumnLength(11),40)
-checkSuccess(cur.getColumnLength('testchar'),40)
-checkSuccess(cur.getColumnLength(12),40)
-checkSuccess(cur.getColumnLength('testvarchar'),40)
+checkSuccess(cur.getColumnLength(11),80)
+checkSuccess(cur.getColumnLength('testchar'),80)
+checkSuccess(cur.getColumnLength(12),80)
+checkSuccess(cur.getColumnLength('testvarchar'),80)
 checkSuccess(cur.getColumnLength(13),1)
 checkSuccess(cur.getColumnLength('testbit'),1)
 print "\n"
